==> vueresizesensor-19.1.19.tgz: package/README.md <==
# VueResizeSensor

A `VueResizeSensor` component is a container that supports resize event. It contains an absolute positioned `<iframe>` element. An inline frame supports the resize event natively. Every time the container resizes, it triggers the resize event of the contained inline frame and the event handler of the inline frame triggers the resize event of the container.

## dependencies

- [Vue](https://github.com/vuejs/vue)

## setup

### npm

```shell
npm install vueresizesensor
```

### ES module

Register the component globally.

```javascript
import Vue from 'vue';
import VueResizeSensor from 'vueresizesensor';

Vue.component(VueResizeSensor.name, VueResizeSensor);
```

*or*

Register the component in the scope of another instance.

```javascript
import VueResizeSensor from 'vueresizesensor';

export default {
  // ...
  components: {
    [VueResizeSensor.name]: VueResizeSensor,
  },
};
```

### browser

```html
<script src="https://unpkg.com/vue"></script>
<script src="https://unpkg.com/vueresizesensor"></script>
```

If Vue is detected, the component will be registered automatically.

## usage

```html
<template>
  <vue-resize-sensor style="width: 100%; height: 100%;" @resize="onResize">
    <div style="display: flex;" :style="{'flex-direction': width > height ? 'row' : 'column'}">
      <div><!--...--></div>
      <div><!--...--></div>
    </div>
    <div v-show="height > 400"><!--...--></div>
  <vue-resize-sensor>
</template>
<script>
export default {
  data: {
    width: 0,
    height: 0,
  },
  methods: {
    onResize({width, height}) {
      this.width = width;
      this.height = height;
    },
  },
};
</script>
```

---

The component renders a `<div>` element by default. You can change the element that is rendered with the `tag` attribute.

```html
<vue-resize-sensor tag="form"><!--...--><vue-resize-sensor>
```

==> vueresizesensor-19.1.21.tgz: package/README.md <==
# VueResizeSensor

A container that supports resize event. It contains an absolute positioned `<iframe>` element. An inline frame supports the resize event natively. Every time the container resizes, it triggers the resize event of the contained inline frame and the event handler of the inline frame triggers the resize event of the container.

## dependencies

- [Vue](https://github.com/vuejs/vue)

## setup

### npm

```shell
npm install vueresizesensor
```

### ES module

Register the component globally.

```javascript
import Vue from 'vue';
import VueResizeSensor from 'vueresizesensor';

Vue.component(VueResizeSensor.name, VueResizeSensor);
```

*or*

Register the component in the scope of another instance.

```javascript
import VueResizeSensor from 'vueresizesensor';

export default {
  // ...
  components: {
    [VueResizeSensor.name]: VueResizeSensor,
  },
};
```

### browser

```html
<script src="https://unpkg.com/vue"></script>
<script src="https://unpkg.com/vueresizesensor"></script>
```

If Vue is detected, the component will be registered automatically.

## usage

```html
<vue-resize-sensor style="width: 100%; height: 100%;">
  <template slot-scope="{w, h}">
    <div style="display: flex;" :style="{'flex-direction': w > h ? 'row' : 'column'}">
      <div><!--...--></div>
      <div><!--...--></div>
    </div>
    <div v-show="h > 400"><!--...--></div>
  </template>
<vue-resize-sensor>
```

---

The component renders a `<div>` element by default. You can change the element that is rendered with the `tag` attribute.

```html
<vue-resize-sensor tag="form"><!--...--><vue-resize-sensor>
```
